
## CATO-CLI - mutation.sites.updateHa:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateHa) for documentation on this operation.

### Usage for mutation.sites.updateHa:

`catocli mutation sites updateHa -h`

`catocli mutation sites updateHa <json>`

`catocli mutation sites updateHa "$(cat < updateHa.json)"`

`catocli mutation sites updateHa '{"siteId": "ID", "updateHaInput": {"primaryManagementIp": {"primaryManagementIp": "IPAddress"}, "secondaryManagementIp": {"secondaryManagementIp": "IPAddress"}, "vrid": {"vrid": "Int"}}}'`

#### Operation Arguments for mutation.sites.updateHa ####
`accountId` [ID] - (required) N/A 
`siteId` [ID] - (required) N/A 
`updateHaInput` [UpdateHaInput] - (required) N/A 
